spacepy.irbempy.sph2car — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »

# spacepy.irbempy.sph2car

`spacepy.irbempy.` `sph2car`(SPHin)

  coordinate transformation from spherical to cartesian

  Parameters: | - SPHin (list or ndarray) : coordinate points in (n,3) shape with n coordinate points in units of [Re, deg, deg] = [r, latitude, longitude]
  Returns: | - results (ndarray) : values after conversion to cartesian coordinates x,y,z

  See also

  `car2sph`

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »